@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vc-msg" "1.1.1"
+(define-package "vc-msg" "20250218.237"
   "Show commit information of current line."
   '((emacs "24.4")
     (popup "0.5.0"))
   :url "http://github.com/redguardtoo/vc-msg"
-  :commit "720c6f0e699f25463cd37642ee23adb4e23bc60b"
-  :revdesc "720c6f0e699f"
+  :commit "d55a128616a876936f085e5af486924062e57d66"
+  :revdesc "d55a128616a8"
   :keywords '("git" "vc" "svn" "hg" "messenger")
   :authors '(("Chen Bin" . "chenbinDOTshATgmailDOTcom"))
   :maintainers '(("Chen Bin" . "chenbinDOTshATgmailDOTcom")))
